@@ -13,7 +13,7 @@ use Imager::Color;
 use List::MoreUtils qw(none);
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -23,7 +23,6 @@ sub new {
 	my $self = bless {}, $class;
 
 	# Background color.
-	$self->{'color_random'} = 1;
 	$self->{'color'} = undef;
 
 	# Image type.
@@ -46,9 +45,6 @@ sub new {
 		err 'Bad background color definition. Use Imager::Color '.
 			'object.';
 	}
-	if (! $self->{'color_random'} && ! defined $self->{'color'}) {
-		err 'Color isn\'t set.';
-	}
 
 	# Check type.
 	if (defined $self->{'type'}) {
@@ -65,13 +61,13 @@ sub create {
 
 	# Background color.
 	my $background;
-	if ($self->{'color_random'}) {
+	if ($self->{'color'}) {
+		$background = $self->{'color'};
+	} else {
 		$background = Imager::Color->new(int rand 256, int rand 256,
 			int rand 256);
-	} else {
-		$background = $self->{'color'};
 	}
-	
+
 	# Create image.
 	$self->{'i'}->box(
 		'color' => $background,
@@ -134,12 +130,12 @@ sub type {
 # Check supported image type.
 sub _check_type {
 	my ($self, $type) = @_;
-	
+
 	# Check type.
 	if (none { $type eq $_ } ('bmp', 'gif', 'jpeg', 'png',
 		'pnm', 'raw', 'sgi', 'tga', 'tiff')) {
 
-		err "Suffix '$type' doesn't supported.";
+		err "Image type '$type' doesn't supported.";
 	}
 
 	return;
@@ -185,15 +181,11 @@ Image::Random - Perl class for creating random image.
 
 =over 8
 
-=item * C<color_random>
-
- Random color flag.
- Default value is 1.
-
 =item * C<color>
 
  Color of image.
- Default value is 'bmp'.
+ Default value is undef.
+ Undefined value means random color.
 
 =item * C<height>
 
@@ -204,7 +196,7 @@ Image::Random - Perl class for creating random image.
 
  Image type.
  List of supported types: bmp, gif, jpeg, png, pnm, raw, sgi, tga, tiff
- Default value is undef.
+ Default value is 'bmp'.
 
 =item * C<width>
 
@@ -234,15 +226,14 @@ Image::Random - Perl class for creating random image.
 
  new():
          Bad background color definition. Use Imager::Color object.
-         Color isn't set.
-         Suffix '%s' doesn't supported.
+         Image type '%s' doesn't supported.
          From Class::Utils:
                  Unknown parameter '%s'.
 
  create():
          Cannot write file to '$path'.
                  Error, %s
-         Suffix '%s' doesn't supported.
+         Image type '%s' doesn't supported.
 
 =head1 EXAMPLE
 
@@ -302,6 +293,6 @@ BSD license.
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
